@@ -46,6 +46,14 @@ preload="auto" {'loop="loop"' if anim.element.loop and int(anim.element.loop) >
 </audio>
 </div>"""
 
+    @staticmethod
+    def animate_controls(*args, delay=0, dwell=0, pause=0):
+        for arg in args:
+            yield '<li style="animation-delay: {0:.2f}s; animation-duration: {1:.2f}s">'.format(delay, dwell)
+            yield arg.strip()
+            yield "</li>"
+            delay += pause
+
     @staticmethod
     def animated_line_to_html(anim):
         name = anim.element.persona.name if hasattr(anim.element.persona, "name") else ""
@@ -138,12 +146,13 @@ pattern="{validator.pattern}"
         stills = "\n".join(Renderer.animated_still_to_html(i) for i in frame[Model.Still])
         audio = "\n".join(Renderer.animated_audio_to_html(i) for i in frame[Model.Audio])
         last = frame[Model.Line][-1] if frame[Model.Line] else Presenter.Animation(0, 0, None)
-        command_form = "<li>{0}</li>".format(Renderer.render_command_form()) if commands else ""
-        action_forms = "\n".join(
-            "<li>\n{0}\n</li>".format("\n".join(Renderer.render_action_form(list(reversed(op.parameters)))))
-            if hasattr(op, "parameters") else ""
-            for op in options
-        ) if actions else ""
+        controls = [Renderer.render_command_form()] if commands else []
+        if actions:
+            controls.extend(
+                Renderer.render_action_form(list(reversed(op.parameters)))
+                for op in actions if hasattr(op, "parameters")
+            )
+        controls = "\n".join(Renderer.animate_controls(*controls, delay=last.delay + last.duration, dwell=0.3))
         return f"""
 {audio}
 <section class="catchphrase-banner">
@@ -159,9 +168,8 @@ pattern="{validator.pattern}"
 </ul>
 </main>
 <nav>
-<ul style="animation-delay: {last.delay:.2f}s; animation-duration: {last.duration:.2f}s">
-{action_forms}
-{command_form}
+<ul>
+{controls}
 </ul>
 </nav>
 </div>"""
@@ -190,7 +198,8 @@ pattern="{validator.pattern}"
 
     @staticmethod
     @functools.lru_cache()
-    def render_body_html(title="", refresh=None, next_="", site_url="/"):
+    def render_body_html(title="", refresh=None, next_="", base_style="/css/base/catchphrase.css"):
+        base_link = '<link rel="stylesheet" href="{0}" />'.format(base_style) if base_style else ""
         return f"""<!DOCTYPE html>
 <html lang="en">
 <head>
@@ -199,7 +208,7 @@ pattern="{validator.pattern}"
 {'<meta http-equiv="refresh" content="{0};{1}">'.format(refresh, next_) if refresh and next_ else ''}
 <meta http-equiv="X-UA-Compatible" content="ie=edge">
 <title>{title}</title>
-<link rel="stylesheet" href="{site_url}css/catchphrase.css" />
+{base_link}
 {{0}}
 </head>
 <body>
